@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from QTKit import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestQTMovieView (TestCase):
     def testConstants(self):
         self.assertIsInstance(QTMovieViewMovieBinding, unicode)
@@ -10,7 +15,7 @@ class TestQTMovieView (TestCase):
         self.assertIsInstance(QTMovieViewFillColorBinding, unicode)
 
     def testProtocols(self):
-        self.assertIsInstance(protocols.QTMovieViewDelegate, objc.informal_protocol)
+        self.assertIsInstance(protocols.QTMovieView_Delegate, objc.informal_protocol)
 
 
     def testMethods(self):
